<?php
/**
 * Plugin Name: WooCommerce Toplist/Sitemap Shortcodes (EasyToolsWP)
 * Description: Shortcodes to display products, product categories, and product tags in WooCommerce.
 * Version: 1.1
 * Author: EasyToolsWP.com
 * Author URI: https://www.easytoolswp.com
 */

// Register shortcode for displaying products
function woocommerce_products_list_shortcode($atts) {
    $atts = shortcode_atts( array(
        'sort' => 'alphabetical', // Default sorting is alphabetical
        'items' => '999' // Default number of items to show
    ), $atts );

    $sort = sanitize_text_field($atts['sort']);
    $items = intval($atts['items']);

    // Set default ordering values
    $orderby = 'title';
    $order = 'ASC';

    // Adjust orderby and order based on sort parameter
    switch ($sort) {
        case 'newest':
            $orderby = 'date';
            $order = 'DESC';
            break;
        case 'most_sold':
            $orderby = 'meta_value_num';
            $order = 'DESC';
            $meta_key = 'total_sales';
            break;
        case 'best_rated':
            $orderby = 'meta_value_num';
            $order = 'DESC';
            $meta_key = '_wc_average_rating';
            break;
        default:
            $orderby = 'title';
            $order = 'ASC';
            break;
    }

    // Query arguments
    $args = array(
        'post_type' => 'product',
        'posts_per_page' => $items,
        'orderby' => $orderby,
        'order' => $order,
    );

    // Add meta key for sorting by total sales or average rating
    if (isset($meta_key)) {
        $args['meta_key'] = $meta_key;
    }

    // Query WooCommerce products
    $products_query = new WP_Query($args);

    // Output products in an unordered list
    $output = '<ul>';
    while ($products_query->have_posts()) {
        $products_query->the_post();
        $output .= '<li><a href="' . get_permalink() . '">' . get_the_title() . '</a></li>';
    }
    $output .= '</ul>';

    // Reset Post Data
    wp_reset_postdata();

    return $output;
}
add_shortcode('woocommerce_products_list', 'woocommerce_products_list_shortcode');

// Register shortcode for displaying product categories
function woocommerce_product_categories_shortcode($atts) {
    $atts = shortcode_atts( array(
        'orderby' => 'name', // Default sorting is by name
        'hide_empty' => false // Show categories even if they are empty
    ), $atts );

    // Extract shortcode attributes
    $orderby = sanitize_text_field($atts['orderby']);
    $hide_empty = filter_var($atts['hide_empty'], FILTER_VALIDATE_BOOLEAN);

    // Get product categories
    $product_categories = get_terms(array(
        'taxonomy' => 'product_cat',
        'orderby' => $orderby,
        'hide_empty' => $hide_empty
    ));

    // Output categories in an unordered list
    $output = '<ul>';
    foreach ($product_categories as $category) {
        $output .= '<li><a href="' . get_term_link($category) . '">' . $category->name . '</a></li>';
    }
    $output .= '</ul>';

    return $output;
}
add_shortcode('woocommerce_product_categories', 'woocommerce_product_categories_shortcode');

// Register shortcode for displaying product tags
function woocommerce_product_tags_shortcode($atts) {
    $atts = shortcode_atts( array(
        'orderby' => 'name', // Default sorting is by name
        'hide_empty' => false // Show tags even if they are empty
    ), $atts );

    // Extract shortcode attributes
    $orderby = sanitize_text_field($atts['orderby']);
    $hide_empty = filter_var($atts['hide_empty'], FILTER_VALIDATE_BOOLEAN);

    // Get product tags
    $product_tags = get_terms(array(
        'taxonomy' => 'product_tag',
        'orderby' => $orderby,
        'hide_empty' => $hide_empty
    ));

    // Output tags in an unordered list
    $output = '<ul>';
    foreach ($product_tags as $tag) {
        $output .= '<li><a href="' . get_term_link($tag) . '">' . $tag->name . '</a></li>';
    }
    $output .= '</ul>';

    return $output;
}
add_shortcode('woocommerce_product_tags', 'woocommerce_product_tags_shortcode');
